@@ -57,7 +57,7 @@ def documents_limited(n):
         @wraps(func)
         def documents_wrapper(*args, **kwargs):
             frames = []
-            for offset in range(0, 4800 + n, n):
+            for offset in range(0, 5000 + n, n):
                 try:
                     frame = func(*args, offset=offset, **kwargs)
                     sleep(0.25)
@@ -71,7 +71,7 @@ def documents_limited(n):
                 raise NoMatchingDataError
 
             df = pd.concat(frames, sort=True)
-            df = df.loc[~df.index.duplicated(keep='first')]
+            df = df.drop_duplicates(keep = 'first')
             return df
         return documents_wrapper
     return decorator
